# Live Image Viewer

Created by Jan Kotanski, last modified on Jan 09, 2020 11:33

### Introduction

This is a simple implementation of a live viewer front end. It is supposed to show a live image view from xray-detectors at PETRA3,

e.g. `Pilatus`, `Lambda`, `Eiger`, `PerkinElmer`, `PCO`, `LimaCCD`, AGIPD, Jungfrau and others.

#### Authors

Christoph Rosemann <christoph.rosemann at desy.de>, Jan Kotański <jan.kotanski at desy.de>, André Rothkirch <andre.rothkirch at desy.de>